Learn R Programming

disclapmix (version 0.2)

plot.disclapmixfit: Plot a disclapmixfit

Description

Is able to plot a wide of different things for a disclapmixfit object.

Usage

## S3 method for class 'disclapmixfit':
plot(x, which = 1, \dots)

Arguments

x
a disclapmixfit object
which
a vector of which plots to do
...
not used

Details

Which can be one or more of the following: 1: Prior probabilities of belonging to a center (tau) 2: v gain (see disclapmix) 3: marginal log likelihood 4: full log likelihood

See Also

disclapmix disclapmixfit predict.disclapmixfit extractMarginalBIC extractFullBIC