powered by
Simulate from a disclapmixfit object.
disclapmixfit
# S3 method for disclapmixfit simulate(object, nsim = 1L, seed = NULL, ...)
A matrix where the rows correspond to the simulated haplotypes.
a disclapmixfit object, usually from a result of a call to disclapmix.
disclapmix
number of haplotypes to generate.
not used
disclapmix disclapmixfit predict.disclapmixfit print.disclapmixfit plot.disclapmixfit summary.disclapmixfit
predict.disclapmixfit
print.disclapmixfit
plot.disclapmixfit
summary.disclapmixfit